@@ -20,9 +20,13 @@
 
 // install a message handler (for Windows)
 #include <QFile>
+#include <QSslSocket>
 #include <QTextStream>
 
+#include <avogadro/core/version.h>
+
 #include "application.h"
+#include "avogadroappconfig.h"
 #include "mainwindow.h"
 
 #ifdef Q_OS_MAC
@@ -49,28 +53,28 @@ void myMessageOutput(QtMsgType type, const QMessageLogContext& context,
   QString message;
   switch (type) {
     case QtInfoMsg:
-      message = QString("Info: %1 (%2:%3, %4)\n")
+      message = QString("Info: %1 (%2:%3, %4)")
                   .arg(localMsg.constData())
                   .arg(file)
                   .arg(context.line)
                   .arg(function);
       break;
     case QtWarningMsg:
-      message = QString("Warning: %1 (%2:%3, %4)\n")
+      message = QString("Warning: %1 (%2:%3, %4)")
                   .arg(localMsg.constData())
                   .arg(file)
                   .arg(context.line)
                   .arg(function);
       break;
     case QtCriticalMsg:
-      message = QString("Critical: %1 (%2:%3, %4)\n")
+      message = QString("Critical: %1 (%2:%3, %4)")
                   .arg(localMsg.constData())
                   .arg(file)
                   .arg(context.line)
                   .arg(function);
       break;
     case QtFatalMsg:
-      message = QString("Fatal: %1 (%2:%3, %4)\n")
+      message = QString("Fatal: %1 (%2:%3, %4)")
                   .arg(localMsg.constData())
                   .arg(file)
                   .arg(context.line)
@@ -78,7 +82,7 @@ void myMessageOutput(QtMsgType type, const QMessageLogContext& context,
       break;
     case QtDebugMsg:
     default:
-      message = QString("Debug: %1 (%2:%3, %4)\n")
+      message = QString("Debug: %1 (%2:%3, %4)")
                   .arg(localMsg.constData())
                   .arg(file)
                   .arg(context.line)
@@ -106,7 +110,7 @@ int main(int argc, char* argv[])
   QCoreApplication::setOrganizationName("OpenChemistry");
   QCoreApplication::setOrganizationDomain("openchemistry.org");
   QCoreApplication::setApplicationName("Avogadro");
-  QGuiApplication::setDesktopFileName("avogadro2");
+  QGuiApplication::setDesktopFileName("org.openchemistry.Avogadro2");
 
   QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
   QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
@@ -115,10 +119,22 @@ int main(int argc, char* argv[])
   // We need to ensure desktop OpenGL is loaded for our rendering.
   QCoreApplication::setAttribute(Qt::AA_UseDesktopOpenGL);
 
+  // remove the previous log file
+  QString writableDocs =
+    QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
+  QFile outFile(writableDocs + "/avogadro2.log");
+  outFile.remove(); // we don't care if this fails
+
   // install the message handler (goes to Documents / avogadro2.log)
   qInstallMessageHandler(myMessageOutput);
 #endif
 
+  // output the version information
+  qDebug() << "Avogadroapp version: " << AvogadroApp_VERSION;
+  qDebug() << "Avogadrolibs version: " << Avogadro::version();
+  qDebug() << "Qt version: " << qVersion();
+  qDebug() << "SSL version: " << QSslSocket::sslLibraryVersionString();
+
   Avogadro::Application app(argc, argv);
 
   QSettings settings;
@@ -268,12 +284,11 @@ int main(int argc, char* argv[])
   }
 
   // Set up the default format for our GL contexts.
+#if defined(Q_OS_MAC)
   QSurfaceFormat defaultFormat = QSurfaceFormat::defaultFormat();
-  defaultFormat.setSamples(4);
-#if defined(Q_OS_MAC) || defined(Q_OS_WIN)
   defaultFormat.setAlphaBufferSize(8);
-#endif
   QSurfaceFormat::setDefaultFormat(defaultFormat);
+#endif
 
   QStringList fileNames;
   bool disableSettings = false;
