@@ -120,7 +120,7 @@ public:
   ~XMLEventObserver() { delete this->XMLStream; }
 
 protected:
-  virtual void setStream(QTextStream* stream)
+  virtual void setStream(QTextStream* stream) override
   {
     if (this->XMLStream) {
       this->XMLStream->writeEndElement();
@@ -142,13 +142,15 @@ protected:
   }
 
   virtual void onRecordEvent(const QString& widget, const QString& command,
-                             const QString& arguments)
+                             const QString& arguments,
+                             const int& eventType = 0) override
   {
     if (this->XMLStream) {
       this->XMLStream->writeStartElement("event");
       this->XMLStream->writeAttribute("widget", widget);
       this->XMLStream->writeAttribute("command", command);
       this->XMLStream->writeAttribute("arguments", arguments);
+      this->XMLStream->writeAttribute("eventType", QString::number(eventType));
       this->XMLStream->writeEndElement();
     }
   }
@@ -168,7 +170,7 @@ public:
   ~XMLEventSource() { delete this->XMLStream; }
 
 protected:
-  virtual void setContent(const QString& xmlfilename)
+  virtual void setContent(const QString& xmlfilename) override
   {
     delete this->XMLStream;
     this->XMLStream = nullptr;
@@ -182,7 +184,8 @@ protected:
     this->XMLStream = new QXmlStreamReader(data);
   }
 
-  int getNextEvent(QString& widget, QString& command, QString& arguments)
+  int getNextEvent(QString& widget, QString& command, QString& arguments,
+                   int& eventType) override
   {
     if (this->XMLStream->atEnd())
       return DONE;
@@ -273,11 +276,16 @@ MainWindow::MainWindow(const QStringList& fileNames, bool disableSettings)
 
   QList<ExtensionPluginFactory*> extensions =
     plugin->pluginFactories<ExtensionPluginFactory>();
+#ifndef NDEBUG
   qDebug() << "Extension plugins dynamically found…" << extensions.size();
+#endif
   foreach (ExtensionPluginFactory* factory, extensions) {
     ExtensionPlugin* extension =
       factory->createInstance(QCoreApplication::instance());
     if (extension) {
+#ifdef Q_OS_WIN
+      qDebug() << " loading extension plugin: " << extension->name();
+#endif
       extension->setParent(this);
       connect(this, &MainWindow::moleculeChanged, extension,
               &QtGui::ExtensionPlugin::setMolecule);
@@ -299,10 +307,19 @@ MainWindow::MainWindow(const QStringList& fileNames, bool disableSettings)
   }
 
   // Now set up the interface.
+#ifdef Q_OS_WIN
+  qDebug() << " setting interface ";
+#endif
   setupInterface();
 
   // Build up the standard menus, incorporate dynamic menus.
+#ifdef Q_OS_WIN
+  qDebug() << " building menu ";
+#endif
   buildMenu();
+#ifdef Q_OS_WIN
+  qDebug() << " updating recent files ";
+#endif
   updateRecentFiles();
 
   // Try to open the file(s) passed in.
@@ -311,6 +328,9 @@ MainWindow::MainWindow(const QStringList& fileNames, bool disableSettings)
     // Give the plugins 5 seconds before timing out queued files.
     QTimer::singleShot(5000, this, &MainWindow::clearQueuedFiles);
   } else {
+#ifdef Q_OS_WIN
+    qDebug() << " creating new molecule ";
+#endif
     newMolecule();
   }
 
@@ -368,6 +388,7 @@ void MainWindow::setupInterface()
   m_multiViewWidget->setFactory(m_viewFactory);
   setCentralWidget(m_multiViewWidget);
   auto* glWidget = new GLWidget(this);
+  m_viewFactory->setGLWidget(glWidget);
 
   // set the background color (alpha channel default should be opaque)
   auto color =
@@ -388,11 +409,15 @@ void MainWindow::setupInterface()
   Rendering::SolidPipeline* pipeline = &glWidget->renderer().solidPipeline();
   if (pipeline) {
     pipeline->setAoEnabled(
-      settings.value("MainWindow/ao_enabled", true).toBool());
+      settings.value("MainWindow/ao_enabled", false).toBool());
+    pipeline->setDofEnabled(
+      settings.value("MainWindow/dof_enabled", false).toBool());
+    pipeline->setFogEnabled(
+      settings.value("MainWindow/fog_enabled", true).toBool());
     pipeline->setAoStrength(
       settings.value("MainWindow/ao_strength", 1.0f).toFloat());
     pipeline->setEdEnabled(
-      settings.value("MainWindow/ed_enabled", true).toBool());
+      settings.value("MainWindow/ed_enabled", false).toBool());
   }
 
   // Our tool dock.
@@ -577,7 +602,7 @@ void setDefaultViews(MultiViewWidget* viewWidget)
     bool anyPluginTrue = false;
     // load plugins normally, if all non-ignore are false.
     // restore the default behavior
-    for (auto plugin : sceneModel->scenePlugins()) {
+    for (ScenePlugin* plugin : sceneModel->scenePlugins()) {
       QString settingsKey("MainWindow/" + plugin->objectName());
       bool enabled = settings.value(settingsKey, plugin->isEnabled()).toBool();
       if (plugin->defaultBehavior() != ScenePlugin::DefaultBehavior::Ignore &&
@@ -844,6 +869,7 @@ bool MainWindow::addScript(const QString& filePath)
   QString typePath;
 
   int index = types.indexOf(item);
+
   // don't translate these
   switch (index) {
     case 0: // commands
@@ -855,10 +881,10 @@ bool MainWindow::addScript(const QString& filePath)
     case 2:
       typePath = "formatScripts";
       break;
-    case 4:
+    case 3:
       typePath = "charges";
       break;
-    case 5:
+    case 4:
       typePath = "energy";
       break;
     default:
@@ -870,8 +896,28 @@ bool MainWindow::addScript(const QString& filePath)
 
   QFileInfo info(filePath);
 
-  QString destinationPath(stdPaths[0] + '/' + typePath + '/' + info.fileName());
+  // check if the directory structure exists first
+  // and if not, create what we need
+  int i = 0;
+  bool createDir = true;
+  for (i = 0; i < stdPaths.size(); ++i) {
+    if (QDir(stdPaths[i] + '/' + typePath).exists()) {
+      createDir = false;
+      break;
+    }
+  }
+  if (createDir) {
+    // find a path we can create (e.g., first path might be admin-only)
+    for (i = 0; i < stdPaths.size(); ++i) {
+      if (QDir().mkpath(stdPaths[i] + '/' + typePath))
+        break;
+    }
+  }
+
+  QString destinationPath(stdPaths[i] + '/' + typePath + '/' + info.fileName());
+#ifndef NDEBUG
   qDebug() << " copying " << filePath << " to " << destinationPath;
+#endif
   QFile::remove(destinationPath); // silently fail if there's nothing to remove
   QFile::copy(filePath, destinationPath);
 
@@ -1497,6 +1543,9 @@ bool MainWindow::saveFileAs(bool async)
   QFileDialog saveDialog(this, tr("Save chemical file"), dir, filter);
   saveDialog.setAcceptMode(QFileDialog::AcceptSave);
   saveDialog.exec();
+  if (saveDialog.selectedFiles().isEmpty()) // user cancel
+    return false;
+
   QString fileName = saveDialog.selectedFiles().first();
 
   if (fileName.isEmpty()) // user cancel
@@ -1800,10 +1849,12 @@ void MainWindow::activeMoleculeEdited()
 
 void MainWindow::setBackgroundColor()
 {
+  Rendering::SolidPipeline* pipeline(nullptr);
   Rendering::Scene* scene(nullptr);
   GLWidget* glWidget(nullptr);
   if ((glWidget = qobject_cast<GLWidget*>(m_multiViewWidget->activeWidget())))
     scene = &glWidget->renderer().scene();
+  pipeline = &glWidget->renderer().solidPipeline();
   if (scene) {
     Vector4ub cColor = scene->backgroundColor();
     QColor qtColor(cColor[0], cColor[1], cColor[2], cColor[3]);
@@ -1814,6 +1865,8 @@ void MainWindow::setBackgroundColor()
       cColor[2] = static_cast<unsigned char>(color.blue());
       cColor[3] = static_cast<unsigned char>(color.alpha());
       scene->setBackgroundColor(cColor);
+      if (pipeline)
+        pipeline->setBackgroundColor(cColor);
       if (glWidget)
         glWidget->update();
 
@@ -1835,6 +1888,8 @@ void MainWindow::setRenderingSettings()
     QSettings settings;
     settings.setValue("MainWindow/ao_enabled", pipeline->getAoEnabled());
     settings.setValue("MainWindow/ao_strength", pipeline->getAoStrength());
+    settings.setValue("MainWindow/dof_enabled", pipeline->getDofEnabled());
+    settings.setValue("MainWindow/fog_enabled", pipeline->getFogEnabled());
     settings.setValue("MainWindow/ed_enabled", pipeline->getEdEnabled());
   }
 }
@@ -2202,6 +2257,9 @@ void MainWindow::buildTools()
 
   int index = 1;
   foreach (ToolPlugin* toolPlugin, m_tools) {
+#ifdef Q_OS_WIN
+    qDebug() << " adding tool " << toolPlugin->objectName();
+#endif
     // Add action to toolbar.
     toolPlugin->setParent(this);
     QAction* action = toolPlugin->activateAction();
@@ -2335,30 +2393,34 @@ bool MainWindow::saveFileIfNeeded()
 
 void MainWindow::registerMoleQueue()
 {
-#ifdef Avogadro_ENABLE_RPC
-  MoleQueue::Client client;
-  if (!client.connectToServer() || !client.isConnected())
-    return;
+  /*
+  #ifdef Avogadro_ENABLE_RPC
+    MoleQueue::Client client;
+    if (!client.connectToServer() || !client.isConnected())
+      return;
 
-  // Get all extensions;
-  typedef std::vector<std::string> StringList;
-  FileFormatManager& ffm = FileFormatManager::instance();
-  StringList exts = ffm.fileExtensions(FileFormat::Read | FileFormat::File);
+    // Get all extensions;
+    typedef std::vector<std::string> StringList;
+    FileFormatManager& ffm = FileFormatManager::instance();
+    StringList exts = ffm.fileExtensions(FileFormat::Read | FileFormat::File);
 
-  // Create patterns list
-  QList<QRegExp> patterns;
-  for (auto it = exts.begin(), itEnd = exts.end(); it != itEnd; ++it) {
-    patterns << QRegExp(extensionToWildCard(QString::fromStdString(*it)),
-                        Qt::CaseInsensitive, QRegExp::Wildcard);
-  }
+    // Create patterns list
+    QList<QRegularExpression> patterns;
+    for (auto it = exts.begin(), itEnd = exts.end(); it != itEnd; ++it) {
+      patterns << QRegularExpression(
+        QRegularExpression::wildcardToRegularExpression(
+          extensionToWildCard(QString::fromStdString(*it))),
+        QRegularExpression::CaseInsensitive);
+    }
 
-  // Register the executable:
-  client.registerOpenWith("Avogadro2 (new)", qApp->applicationFilePath(),
-                          patterns);
+    // Register the executable:
+    client.registerOpenWith("Avogadro2 (new)", qApp->applicationFilePath(),
+                            patterns);
 
-  client.registerOpenWith("Avogadro2 (running)", "avogadro", "openFile",
-                          patterns);
-#endif // Avogadro_ENABLE_RPC
+    client.registerOpenWith("Avogadro2 (running)", "avogadro", "openFile",
+                            patterns);
+  #endif // Avogadro_ENABLE_RPC
+  */
 }
 
 void MainWindow::showAboutDialog()
@@ -2369,10 +2431,11 @@ void MainWindow::showAboutDialog()
 
 void MainWindow::openURL(const QString& url)
 {
-#if defined(Q_OS_MAC) || defined(Q_OS_WIN)
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0) || defined(Q_OS_MAC) ||            \
+  defined(Q_OS_WIN)
   QDesktopServices::openUrl(url);
 #else
-  // AppImage can't use QDesktopServices::openUrl, so we use QProcess:
+  // On Qt5, AppImage can't use QDesktopServices::openUrl, so we use QProcess:
   QProcess::execute(QString("xdg-open %1").arg(url));
 #endif
 }
@@ -2410,7 +2473,9 @@ void MainWindow::finishUpdateRequest(QNetworkReply* reply)
     settings.value("currentVersion", AvogadroApp_VERSION).toString();
   // could be something like 1.97.0-36-gcd224f0
 
-  // qDebug() << " update comparing " << lastVersion << " to " << latestRelease;
+#ifndef NDEBUG
+  qDebug() << " update comparing " << lastVersion << " to " << latestRelease;
+#endif
   QStringList releaseComponents = latestRelease.split('.');
   QStringList currentComponents = lastVersion.split('.');
   if (releaseComponents.size() != 3 || currentComponents.size() != 3)
