@@ -8,6 +8,9 @@
 #include <QtCore/QDebug>
 #include <QtWidgets/QMenuBar>
 
+#include <algorithm>
+#include <utility>
+
 namespace Avogadro {
 
 namespace {
@@ -18,7 +21,7 @@ namespace {
  */
 struct PriorityText
 {
-  PriorityText(const QString& string, int pri) : text(string), priority(pri) {}
+  PriorityText(QString  string, int pri) : text(std::move(string)), priority(pri) {}
 
   QString text;
   int priority;
@@ -165,7 +168,7 @@ void MenuBuilder::buildMenu(QMenu* menu, const QString& path)
     }
   }
 
-  qSort(actionText.begin(), actionText.end(), lessThan);
+  std::sort(actionText.begin(), actionText.end(), lessThan);
 
   // When an action's priority is below this value, insert a separator.
   // Separators are inserted as needed at multiples of 100.
@@ -198,7 +201,7 @@ void MenuBuilder::buildMenu(QMenu* menu, const QString& path)
         if (action->text() == text.text) {
           // build the new submenu, insert,
           // then remove the placeholder
-          QMenu* subMenu = new QMenu(text.text, menu);
+          auto* subMenu = new QMenu(text.text, menu);
           buildMenu(subMenu, submenuMap[text.text]);
           menu->insertMenu(action, subMenu);
           menu->removeAction(action);
