@@ -62,6 +62,14 @@ public:
    */
   void print();
 
+  /**
+   * @brief Get the map of string to action lists.
+   */
+  const QMap<QString, QList<QAction*>>& getMenuActions() const
+  {
+    return m_menuActions;
+  };
+
 private:
   /** A map of string to action lists. */
   QMap<QString, QList<QAction*>> m_menuActions;
